@@ -11,9 +11,6 @@ class BaseHandler(RequestHandler):
     def initialize(self, *args, **kw):
         super(BaseHandler, self).initialize(*args, **kw)
 
-    def keep_alive(self):
-        return False
-
     def on_finish(self):
         if self.application.config.COMMIT_ON_REQUEST_END:
             if self.get_status() > 399:
@@ -24,14 +21,6 @@ class BaseHandler(RequestHandler):
                 self.db.commit()
                 self.application.event_bus.flush()
 
-    def finish(self, chunk=None):
-        keep_alive = self.keep_alive()
-
-        if not keep_alive:
-            self.request.connection.no_keep_alive = False
-
-        super(BaseHandler, self).finish(chunk)
-
     def options(self):
         self.set_header('Access-Control-Allow-Origin', self.application.config.ORIGIN)
         self.set_header('Access-Control-Allow-Methods', 'GET,PUT,POST,DELETE,OPTIONS')
